@@ -1,6 +1,6 @@
-/* Copyright (c) 2015-2024 The Khronos Group Inc.
- * Copyright (c) 2015-2024 Valve Corporation
- * Copyright (c) 2015-2024 LunarG, Inc.
+/* Copyright (c) 2015-2025 The Khronos Group Inc.
+ * Copyright (c) 2015-2025 Valve Corporation
+ * Copyright (c) 2015-2025 LunarG, Inc.
  * Modifications Copyright (C) 2020 Advanced Micro Devices, Inc. All rights reserved.
  * Modifications Copyright (C) 2022 RasterGrid Kft.
  *
@@ -194,10 +194,10 @@ void BestPractices::PostCallRecordCmdSetDepthTestEnableEXT(VkCommandBuffer comma
 
 namespace {
 struct EventValidator {
-    const ValidationStateTracker& state_tracker;
+    const vvl::Device& state_tracker;
     vvl::unordered_map<VkEvent, bool> signaling_state;
 
-    EventValidator(const ValidationStateTracker& state_tracker) : state_tracker(state_tracker) {}
+    EventValidator(const vvl::Device& state_tracker) : state_tracker(state_tracker) {}
 
     bool ValidateSecondaryCbSignalingState(const bp_state::CommandBuffer& primary_cb, const bp_state::CommandBuffer& secondary_cb,
                                            const Location& secondary_cb_loc) {
