@@ -578,18 +578,18 @@ bool CoreChecks::PreCallValidateCmdExecuteGeneratedCommandsEXT(VkCommandBuffer c
             "was created with VK_INDIRECT_COMMANDS_LAYOUT_USAGE_EXPLICIT_PREPROCESS_BIT_EXT but isPreprocessed is VK_FALSE.");
     }
 
-    if (cb_state.activeRenderPass) {
+    if (const vvl::RenderPass* rp_state = cb_state.active_render_pass.get()) {
         uint32_t view_mask = 0;
-        if (cb_state.activeRenderPass->UsesDynamicRendering()) {
-            view_mask = cb_state.activeRenderPass->dynamic_rendering_begin_rendering_info.viewMask;
+        if (rp_state->UsesDynamicRendering()) {
+            view_mask = rp_state->dynamic_rendering_begin_rendering_info.viewMask;
         } else {
-            const auto* render_pass_info = cb_state.activeRenderPass->create_info.ptr();
+            const auto* render_pass_info = rp_state->create_info.ptr();
             const auto subpass_desc = render_pass_info->pSubpasses[cb_state.GetActiveSubpass()];
             view_mask = subpass_desc.viewMask;
         }
         if (view_mask != 0) {
             skip |= LogError("VUID-vkCmdExecuteGeneratedCommandsEXT-None-11062", commandBuffer, error_obj.location,
-                             "The active render pass contains a non-zero view mask (%" PRIu32 ").", view_mask);
+                             "The active render pass contains a non-zero viewMask (0x%" PRIx32 ").", view_mask);
         }
     }
 
@@ -629,7 +629,7 @@ bool CoreChecks::ValidateGeneratedCommandsInitialShaderState(const vvl::CommandB
 
     const VkPipelineBindPoint bind_point = ConvertToPipelineBindPoint(shader_stage_flags);
     const auto lv_bind_point = ConvertToLvlBindPoint(bind_point);
-    const auto& last_bound = cb_state.lastBound[lv_bind_point];
+    const LastBound& last_bound = cb_state.lastBound[lv_bind_point];
 
     if (indirect_execution_set.is_pipeline) {
         const vvl::Pipeline* pipeline = last_bound.pipeline_state;
