@@ -1,6 +1,6 @@
-/* Copyright (c) 2015-2024 The Khronos Group Inc.
- * Copyright (c) 2015-2024 Valve Corporation
- * Copyright (c) 2015-2024 LunarG, Inc.
+/* Copyright (c) 2015-2025 The Khronos Group Inc.
+ * Copyright (c) 2015-2025 Valve Corporation
+ * Copyright (c) 2015-2025 LunarG, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -174,6 +174,7 @@ class TypedHandleWrapper {
 struct Location;
 
 struct MessageFormatSettings {
+    bool json = false;
     bool display_application_name = false;
     std::string application_name;
 };
@@ -199,6 +200,7 @@ class DebugReport {
     bool force_default_log_callback{false};
     uint32_t device_created = 0;
     MessageFormatSettings message_format_settings;
+    bool debug_stable_messages{false};
 
     void SetUtilsObjectName(const VkDebugUtilsObjectNameInfoEXT *pNameInfo);
     void SetMarkerObjectName(const VkDebugMarkerObjectNameInfoEXT *pNameInfo);
@@ -221,11 +223,12 @@ class DebugReport {
         return FormatHandle(VkHandleInfo<T>::Typename(), HandleToUint64(handle));
     }
 
-    // Formats messages to be in the proper format, handles VUID logic, and any legacy issues
-    bool LogMsg(VkFlags msg_flags, const LogObjectList &objects, const Location &loc, std::string_view vuid_text,
-                const char *format, va_list argptr);
-    // Core logging that interacts with the DebugCallbacks
-    bool DebugLogMsg(VkFlags msg_flags, const LogObjectList &objects, const char *msg, const char *text_vuid) const;
+    // Legacy way to log messages with C-style va_list
+    bool LogMessageVaList(VkFlags msg_flags, std::string_view vuid_text, const LogObjectList &objects, const Location &loc,
+                          const char *format, va_list argptr);
+    // Formats messages to be in the proper format, handles VUID logic, any legacy issues, and finally calls the callback
+    bool LogMessage(VkFlags msg_flags, std::string_view vuid_text, const LogObjectList &objects, const Location &loc,
+                    const std::string &main_message);
 
     void BeginQueueDebugUtilsLabel(VkQueue queue, const VkDebugUtilsLabelEXT *label_info);
     void EndQueueDebugUtilsLabel(VkQueue queue);
@@ -239,8 +242,12 @@ class DebugReport {
 
   private:
     bool UpdateLogMsgCounts(int32_t vuid_hash) const;
-    bool LogMsgEnabled(std::string_view vuid_text, VkDebugUtilsMessageSeverityFlagsEXT msg_severity,
+    bool LogMsgEnabled(uint32_t vuid_hash, VkDebugUtilsMessageSeverityFlagsEXT msg_severity,
                        VkDebugUtilsMessageTypeFlagsEXT msg_type);
+    std::string CreateMessageText(const Location &loc, std::string_view vuid_text, const std::string &main_message);
+    std::string CreateMessageJson(VkFlags msg_flags, const Location &loc,
+                                  const std::vector<VkDebugUtilsObjectNameInfoEXT> &object_name_infos, const uint32_t vuid_hash,
+                                  std::string_view vuid_text, const std::string &main_message);
 
     VkDebugUtilsMessageSeverityFlagsEXT active_msg_severities{0};
     VkDebugUtilsMessageTypeFlagsEXT active_msg_types{0};
@@ -265,7 +272,7 @@ class Logger {
         LogError(std::string_view vuid_text, const LogObjectList &objlist, const Location &loc, const char *format, ...) const {
         va_list argptr;
         va_start(argptr, format);
-        const bool result = debug_report->LogMsg(kErrorBit, objlist, loc, vuid_text, format, argptr);
+        const bool result = debug_report->LogMessageVaList(kErrorBit, vuid_text, objlist, loc, format, argptr);
         va_end(argptr);
         return result;
     }
@@ -275,7 +282,7 @@ class Logger {
                                                  const char *format, ...) const {
         va_list argptr;
         va_start(argptr, format);
-        const bool result = debug_report->LogMsg(kWarningBit, objlist, loc, vuid_text, format, argptr);
+        const bool result = debug_report->LogMessageVaList(kWarningBit, vuid_text, objlist, loc, format, argptr);
         va_end(argptr);
         return result;
     }
@@ -284,7 +291,7 @@ class Logger {
         LogWarning(std::string_view vuid_text, const LogObjectList &objlist, const Location &loc, const char *format, ...) const {
         va_list argptr;
         va_start(argptr, format);
-        const bool result = debug_report->LogMsg(kWarningBit, objlist, loc, vuid_text, format, argptr);
+        const bool result = debug_report->LogMessageVaList(kWarningBit, vuid_text, objlist, loc, format, argptr);
         va_end(argptr);
         return result;
     }
@@ -293,7 +300,7 @@ class Logger {
                                                      const char *format, ...) const {
         va_list argptr;
         va_start(argptr, format);
-        const bool result = debug_report->LogMsg(kPerformanceWarningBit, objlist, loc, vuid_text, format, argptr);
+        const bool result = debug_report->LogMessageVaList(kPerformanceWarningBit, vuid_text, objlist, loc, format, argptr);
         va_end(argptr);
         return result;
     }
@@ -302,7 +309,7 @@ class Logger {
         LogInfo(std::string_view vuid_text, const LogObjectList &objlist, const Location &loc, const char *format, ...) const {
         va_list argptr;
         va_start(argptr, format);
-        const bool result = debug_report->LogMsg(kInformationBit, objlist, loc, vuid_text, format, argptr);
+        const bool result = debug_report->LogMessageVaList(kInformationBit, vuid_text, objlist, loc, format, argptr);
         va_end(argptr);
         return result;
     }
@@ -311,7 +318,7 @@ class Logger {
         LogVerbose(std::string_view vuid_text, const LogObjectList &objlist, const Location &loc, const char *format, ...) const {
         va_list argptr;
         va_start(argptr, format);
-        const bool result = debug_report->LogMsg(kVerboseBit, objlist, loc, vuid_text, format, argptr);
+        const bool result = debug_report->LogMessageVaList(kVerboseBit, vuid_text, objlist, loc, format, argptr);
         va_end(argptr);
         return result;
     }
