@@ -1,6 +1,6 @@
-/* Copyright (c) 2015-2024 The Khronos Group Inc.
- * Copyright (c) 2015-2024 Valve Corporation
- * Copyright (c) 2015-2024 LunarG, Inc.
+/* Copyright (c) 2015-2025 The Khronos Group Inc.
+ * Copyright (c) 2015-2025 Valve Corporation
+ * Copyright (c) 2015-2025 LunarG, Inc.
  * Copyright (C) 2015-2024 Google Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -20,10 +20,13 @@
 #include "generated/enum_flag_bits.h"
 #include "generated/dispatch_functions.h"
 
-bool StatelessValidation::manual_PreCallValidateGetMemoryFdKHR(VkDevice device, const VkMemoryGetFdInfoKHR *pGetFdInfo, int *pFd,
-                                                               const ErrorObject &error_obj) const {
+namespace stateless {
+
+bool Device::manual_PreCallValidateGetMemoryFdKHR(VkDevice device, const VkMemoryGetFdInfoKHR *pGetFdInfo, int *pFd,
+                                                  const Context &context) const {
     constexpr auto allowed_types = VK_EXTERNAL_MEMORY_HANDLE_TYPE_OPAQUE_FD_BIT | VK_EXTERNAL_MEMORY_HANDLE_TYPE_DMA_BUF_BIT_EXT;
     bool skip = false;
+    const auto &error_obj = context.error_obj;
     if (0 == (pGetFdInfo->handleType & allowed_types)) {
         skip |= LogError("VUID-VkMemoryGetFdInfoKHR-handleType-00672", pGetFdInfo->memory,
                          error_obj.location.dot(Field::pGetFdInfo).dot(Field::handleType),
@@ -34,11 +37,11 @@ bool StatelessValidation::manual_PreCallValidateGetMemoryFdKHR(VkDevice device,
     return skip;
 }
 
-bool StatelessValidation::manual_PreCallValidateGetMemoryFdPropertiesKHR(VkDevice device,
-                                                                         VkExternalMemoryHandleTypeFlagBits handleType, int fd,
-                                                                         VkMemoryFdPropertiesKHR *pMemoryFdProperties,
-                                                                         const ErrorObject &error_obj) const {
+bool Device::manual_PreCallValidateGetMemoryFdPropertiesKHR(VkDevice device, VkExternalMemoryHandleTypeFlagBits handleType, int fd,
+                                                            VkMemoryFdPropertiesKHR *pMemoryFdProperties,
+                                                            const Context &context) const {
     bool skip = false;
+    const auto &error_obj = context.error_obj;
     if (fd < 0) {
         skip |= LogError("VUID-vkGetMemoryFdPropertiesKHR-fd-00673", device, error_obj.location.dot(Field::fd),
                          "handle (%d) is not a valid POSIX file descriptor.", fd);
@@ -50,10 +53,9 @@ bool StatelessValidation::manual_PreCallValidateGetMemoryFdPropertiesKHR(VkDevic
     return skip;
 }
 
-bool StatelessValidation::ValidateExternalSemaphoreHandleType(VkSemaphore semaphore, const char *vuid,
-                                                              const Location &handle_type_loc,
-                                                              VkExternalSemaphoreHandleTypeFlagBits handle_type,
-                                                              VkExternalSemaphoreHandleTypeFlags allowed_types) const {
+bool Device::ValidateExternalSemaphoreHandleType(VkSemaphore semaphore, const char *vuid, const Location &handle_type_loc,
+                                                 VkExternalSemaphoreHandleTypeFlagBits handle_type,
+                                                 VkExternalSemaphoreHandleTypeFlags allowed_types) const {
     bool skip = false;
     if (0 == (handle_type & allowed_types)) {
         skip |= LogError(vuid, semaphore, handle_type_loc, "%s is not one of the supported handleTypes (%s).",
@@ -63,9 +65,9 @@ bool StatelessValidation::ValidateExternalSemaphoreHandleType(VkSemaphore semaph
     return skip;
 }
 
-bool StatelessValidation::ValidateExternalFenceHandleType(VkFence fence, const char *vuid, const Location &handle_type_loc,
-                                                          VkExternalFenceHandleTypeFlagBits handle_type,
-                                                          VkExternalFenceHandleTypeFlags allowed_types) const {
+bool Device::ValidateExternalFenceHandleType(VkFence fence, const char *vuid, const Location &handle_type_loc,
+                                             VkExternalFenceHandleTypeFlagBits handle_type,
+                                             VkExternalFenceHandleTypeFlags allowed_types) const {
     bool skip = false;
     if (0 == (handle_type & allowed_types)) {
         skip |= LogError(vuid, fence, handle_type_loc, "%s is not one of the supported handleTypes (%s).",
@@ -78,17 +80,18 @@ bool StatelessValidation::ValidateExternalFenceHandleType(VkFence fence, const c
 static constexpr VkExternalSemaphoreHandleTypeFlags kSemFdHandleTypes =
     VK_EXTERNAL_SEMAPHORE_HANDLE_TYPE_OPAQUE_FD_BIT | VK_EXTERNAL_SEMAPHORE_HANDLE_TYPE_SYNC_FD_BIT;
 
-bool StatelessValidation::manual_PreCallValidateGetSemaphoreFdKHR(VkDevice device, const VkSemaphoreGetFdInfoKHR *pGetFdInfo,
-                                                                  int *pFd, const ErrorObject &error_obj) const {
+bool Device::manual_PreCallValidateGetSemaphoreFdKHR(VkDevice device, const VkSemaphoreGetFdInfoKHR *pGetFdInfo, int *pFd,
+                                                     const Context &context) const {
+    const auto &error_obj = context.error_obj;
     return ValidateExternalSemaphoreHandleType(pGetFdInfo->semaphore, "VUID-VkSemaphoreGetFdInfoKHR-handleType-01136",
                                                error_obj.location.dot(Field::pGetFdInfo).dot(Field::handleType),
                                                pGetFdInfo->handleType, kSemFdHandleTypes);
 }
 
-bool StatelessValidation::manual_PreCallValidateImportSemaphoreFdKHR(VkDevice device,
-                                                                     const VkImportSemaphoreFdInfoKHR *pImportSemaphoreFdInfo,
-                                                                     const ErrorObject &error_obj) const {
+bool Device::manual_PreCallValidateImportSemaphoreFdKHR(VkDevice device, const VkImportSemaphoreFdInfoKHR *pImportSemaphoreFdInfo,
+                                                        const Context &context) const {
     bool skip = false;
+    const auto &error_obj = context.error_obj;
     const Location info_loc = error_obj.location.dot(Field::pImportSemaphoreFdInfo);
     skip |=
         ValidateExternalSemaphoreHandleType(pImportSemaphoreFdInfo->semaphore, "VUID-VkImportSemaphoreFdInfoKHR-handleType-01143",
@@ -108,16 +111,17 @@ bool StatelessValidation::manual_PreCallValidateImportSemaphoreFdKHR(VkDevice de
 static constexpr VkExternalFenceHandleTypeFlags kFenceFdHandleTypes =
     VK_EXTERNAL_FENCE_HANDLE_TYPE_OPAQUE_FD_BIT | VK_EXTERNAL_FENCE_HANDLE_TYPE_SYNC_FD_BIT;
 
-bool StatelessValidation::manual_PreCallValidateGetFenceFdKHR(VkDevice device, const VkFenceGetFdInfoKHR *pGetFdInfo, int *pFd,
-                                                              const ErrorObject &error_obj) const {
+bool Device::manual_PreCallValidateGetFenceFdKHR(VkDevice device, const VkFenceGetFdInfoKHR *pGetFdInfo, int *pFd,
+                                                 const Context &context) const {
     return ValidateExternalFenceHandleType(pGetFdInfo->fence, "VUID-VkFenceGetFdInfoKHR-handleType-01456",
-                                           error_obj.location.dot(Field::pGetFdInfo).dot(Field::handleType), pGetFdInfo->handleType,
-                                           kFenceFdHandleTypes);
+                                           context.error_obj.location.dot(Field::pGetFdInfo).dot(Field::handleType),
+                                           pGetFdInfo->handleType, kFenceFdHandleTypes);
 }
 
-bool StatelessValidation::manual_PreCallValidateImportFenceFdKHR(VkDevice device, const VkImportFenceFdInfoKHR *pImportFenceFdInfo,
-                                                                 const ErrorObject &error_obj) const {
+bool Device::manual_PreCallValidateImportFenceFdKHR(VkDevice device, const VkImportFenceFdInfoKHR *pImportFenceFdInfo,
+                                                    const Context &context) const {
     bool skip = false;
+    const auto &error_obj = context.error_obj;
     const Location info_loc = error_obj.location.dot(Field::pImportFenceFdInfo);
     skip |= ValidateExternalFenceHandleType(pImportFenceFdInfo->fence, "VUID-VkImportFenceFdInfoKHR-handleType-01464",
                                             info_loc.dot(Field::handleType), pImportFenceFdInfo->handleType, kFenceFdHandleTypes);
@@ -132,10 +136,12 @@ bool StatelessValidation::manual_PreCallValidateImportFenceFdKHR(VkDevice device
     return skip;
 }
 
-bool StatelessValidation::manual_PreCallValidateGetMemoryHostPointerPropertiesEXT(
-    VkDevice device, VkExternalMemoryHandleTypeFlagBits handleType, const void *pHostPointer,
-    VkMemoryHostPointerPropertiesEXT *pMemoryHostPointerProperties, const ErrorObject &error_obj) const {
+bool Device::manual_PreCallValidateGetMemoryHostPointerPropertiesEXT(VkDevice device, VkExternalMemoryHandleTypeFlagBits handleType,
+                                                                     const void *pHostPointer,
+                                                                     VkMemoryHostPointerPropertiesEXT *pMemoryHostPointerProperties,
+                                                                     const Context &context) const {
     bool skip = false;
+    const auto &error_obj = context.error_obj;
     if (handleType != VK_EXTERNAL_MEMORY_HANDLE_TYPE_HOST_ALLOCATION_BIT_EXT &&
         handleType != VK_EXTERNAL_MEMORY_HANDLE_TYPE_HOST_MAPPED_FOREIGN_MEMORY_BIT_EXT) {
         skip |=
@@ -157,9 +163,9 @@ bool StatelessValidation::manual_PreCallValidateGetMemoryHostPointerPropertiesEX
 }
 
 #ifdef VK_USE_PLATFORM_WIN32_KHR
-bool StatelessValidation::manual_PreCallValidateGetMemoryWin32HandleKHR(VkDevice device,
-                                                                        const VkMemoryGetWin32HandleInfoKHR *pGetWin32HandleInfo,
-                                                                        HANDLE *pHandle, const ErrorObject &error_obj) const {
+bool Device::manual_PreCallValidateGetMemoryWin32HandleKHR(VkDevice device,
+                                                           const VkMemoryGetWin32HandleInfoKHR *pGetWin32HandleInfo,
+                                                           HANDLE *pHandle, const Context &context) const {
     constexpr VkExternalMemoryHandleTypeFlags nt_handles =
         VK_EXTERNAL_MEMORY_HANDLE_TYPE_OPAQUE_WIN32_BIT | VK_EXTERNAL_MEMORY_HANDLE_TYPE_D3D11_TEXTURE_BIT |
         VK_EXTERNAL_MEMORY_HANDLE_TYPE_D3D12_HEAP_BIT | VK_EXTERNAL_MEMORY_HANDLE_TYPE_D3D12_RESOURCE_BIT;
@@ -168,7 +174,7 @@ bool StatelessValidation::manual_PreCallValidateGetMemoryWin32HandleKHR(VkDevice
     bool skip = false;
     if ((pGetWin32HandleInfo->handleType & (nt_handles | global_share_handles)) == 0) {
         skip |= LogError("VUID-VkMemoryGetWin32HandleInfoKHR-handleType-00664", pGetWin32HandleInfo->memory,
-                         error_obj.location.dot(Field::pGetWin32HandleInfo).dot(Field::handleType),
+                         context.error_obj.location.dot(Field::pGetWin32HandleInfo).dot(Field::handleType),
                          "(%s) is not one of the supported handle types (%s).",
                          string_VkExternalMemoryHandleTypeFlagBits(pGetWin32HandleInfo->handleType),
                          string_VkExternalMemoryHandleTypeFlags(nt_handles | global_share_handles).c_str());
@@ -176,10 +182,12 @@ bool StatelessValidation::manual_PreCallValidateGetMemoryWin32HandleKHR(VkDevice
     return skip;
 }
 
-bool StatelessValidation::manual_PreCallValidateGetMemoryWin32HandlePropertiesKHR(
-    VkDevice device, VkExternalMemoryHandleTypeFlagBits handleType, HANDLE handle,
-    VkMemoryWin32HandlePropertiesKHR *pMemoryWin32HandleProperties, const ErrorObject &error_obj) const {
+bool Device::manual_PreCallValidateGetMemoryWin32HandlePropertiesKHR(VkDevice device, VkExternalMemoryHandleTypeFlagBits handleType,
+                                                                     HANDLE handle,
+                                                                     VkMemoryWin32HandlePropertiesKHR *pMemoryWin32HandleProperties,
+                                                                     const Context &context) const {
     bool skip = false;
+    const auto &error_obj = context.error_obj;
     if (handle == NULL || handle == INVALID_HANDLE_VALUE) {
         static_assert(sizeof(HANDLE) == sizeof(uintptr_t));  // to use PRIxPTR for HANDLE formatting
         skip |= LogError("VUID-vkGetMemoryWin32HandlePropertiesKHR-handle-00665", device, error_obj.location.dot(Field::handle),
@@ -198,10 +206,10 @@ static constexpr VkExternalSemaphoreHandleTypeFlags kSemWin32HandleTypes = VK_EX
                                                                            VK_EXTERNAL_SEMAPHORE_HANDLE_TYPE_OPAQUE_WIN32_KMT_BIT |
                                                                            VK_EXTERNAL_SEMAPHORE_HANDLE_TYPE_D3D12_FENCE_BIT;
 
-bool StatelessValidation::manual_PreCallValidateImportSemaphoreWin32HandleKHR(VkDevice device,
-                                                                              const VkImportSemaphoreWin32HandleInfoKHR *info,
-                                                                              const ErrorObject &error_obj) const {
+bool Device::manual_PreCallValidateImportSemaphoreWin32HandleKHR(VkDevice device, const VkImportSemaphoreWin32HandleInfoKHR *info,
+                                                                 const Context &context) const {
     bool skip = false;
+    const auto &error_obj = context.error_obj;
 
     skip |=
         ValidateExternalSemaphoreHandleType(info->semaphore, "VUID-VkImportSemaphoreWin32HandleInfoKHR-handleType-01140",
@@ -224,21 +232,20 @@ bool StatelessValidation::manual_PreCallValidateImportSemaphoreWin32HandleKHR(Vk
     return skip;
 }
 
-bool StatelessValidation::manual_PreCallValidateGetSemaphoreWin32HandleKHR(VkDevice device,
-                                                                           const VkSemaphoreGetWin32HandleInfoKHR *info,
-                                                                           HANDLE *pHandle, const ErrorObject &error_obj) const {
+bool Device::manual_PreCallValidateGetSemaphoreWin32HandleKHR(VkDevice device, const VkSemaphoreGetWin32HandleInfoKHR *info,
+                                                              HANDLE *pHandle, const Context &context) const {
     return ValidateExternalSemaphoreHandleType(info->semaphore, "VUID-VkSemaphoreGetWin32HandleInfoKHR-handleType-01131",
-                                               error_obj.location.dot(Field::pGetWin32HandleInfo).dot(Field::handleType),
+                                               context.error_obj.location.dot(Field::pGetWin32HandleInfo).dot(Field::handleType),
                                                info->handleType, kSemWin32HandleTypes);
 }
 
 static constexpr VkExternalFenceHandleTypeFlags kFenceWin32HandleTypes =
     VK_EXTERNAL_FENCE_HANDLE_TYPE_OPAQUE_WIN32_BIT | VK_EXTERNAL_FENCE_HANDLE_TYPE_OPAQUE_WIN32_KMT_BIT;
 
-bool StatelessValidation::manual_PreCallValidateImportFenceWin32HandleKHR(VkDevice device,
-                                                                          const VkImportFenceWin32HandleInfoKHR *info,
-                                                                          const ErrorObject &error_obj) const {
+bool Device::manual_PreCallValidateImportFenceWin32HandleKHR(VkDevice device, const VkImportFenceWin32HandleInfoKHR *info,
+                                                             const Context &context) const {
     bool skip = false;
+    const auto &error_obj = context.error_obj;
     skip |= ValidateExternalFenceHandleType(info->fence, "VUID-VkImportFenceWin32HandleInfoKHR-handleType-01457",
                                             error_obj.location.dot(Field::pImportFenceWin32HandleInfo).dot(Field::handleType),
                                             info->handleType, kFenceWin32HandleTypes);
@@ -258,8 +265,9 @@ bool StatelessValidation::manual_PreCallValidateImportFenceWin32HandleKHR(VkDevi
     return skip;
 }
 
-bool StatelessValidation::manual_PreCallValidateGetFenceWin32HandleKHR(VkDevice device, const VkFenceGetWin32HandleInfoKHR *info,
-                                                                       HANDLE *pHandle, const ErrorObject &error_obj) const {
+bool Device::manual_PreCallValidateGetFenceWin32HandleKHR(VkDevice device, const VkFenceGetWin32HandleInfoKHR *info,
+                                                          HANDLE *pHandle, const Context &context) const {
+    const auto &error_obj = context.error_obj;
     return ValidateExternalFenceHandleType(info->fence, "VUID-VkFenceGetWin32HandleInfoKHR-handleType-01452",
                                            error_obj.location.dot(Field::pGetWin32HandleInfo).dot(Field::handleType),
                                            info->handleType, kFenceWin32HandleTypes);
@@ -267,8 +275,8 @@ bool StatelessValidation::manual_PreCallValidateGetFenceWin32HandleKHR(VkDevice
 #endif
 
 #ifdef VK_USE_PLATFORM_METAL_EXT
-bool StatelessValidation::ExportMetalObjectsPNextUtil(VkExportMetalObjectTypeFlagBitsEXT bit, const char *vuid, const Location &loc,
-                                                      const char *sType, const void *pNext) const {
+bool Device::ExportMetalObjectsPNextUtil(VkExportMetalObjectTypeFlagBitsEXT bit, const char *vuid, const Location &loc,
+                                         const char *sType, const void *pNext) const {
     bool skip = false;
     auto export_metal_object_info = vku::FindStructInPNextChain<VkExportMetalObjectCreateInfoEXT>(pNext);
     while (export_metal_object_info) {
@@ -363,12 +371,18 @@ ExternalOperationsInfo GetExternalOperationsInfo(const void *pNext) {
     ext.total_import_ops += (import_info_qnx && import_info_qnx->buffer);
 #endif  // VK_USE_PLATFORM_SCREEN_QNX
 
+#ifdef VK_USE_PLATFORM_METAL_EXT
+    // VK_EXT_external_memory_metal
+    auto import_info_metal = vku::FindStructInPNextChain<VkImportMemoryMetalHandleInfoEXT>(pNext);
+    ext.total_import_ops += (import_info_metal && import_info_metal->handle);
+#endif // VK_USE_PLATFORM_METAL_EXT
+
     return ext;
 }
 }  // namespace
 
-bool StatelessValidation::ValidateAllocateMemoryExternal(VkDevice device, const VkMemoryAllocateInfo &allocate_info,
-                                                         VkMemoryAllocateFlags flags, const Location &allocate_info_loc) const {
+bool Device::ValidateAllocateMemoryExternal(VkDevice device, const VkMemoryAllocateInfo &allocate_info, VkMemoryAllocateFlags flags,
+                                            const Location &allocate_info_loc) const {
     bool skip = false;
 
     // Used to remove platform ifdef logic below
@@ -505,3 +519,4 @@ bool StatelessValidation::ValidateAllocateMemoryExternal(VkDevice device, const
 
     return skip;
 }
+}  // namespace stateless
