@@ -1,6 +1,6 @@
-/* Copyright (c) 2015-2024 The Khronos Group Inc.
- * Copyright (c) 2015-2024 Valve Corporation
- * Copyright (c) 2015-2024 LunarG, Inc.
+/* Copyright (c) 2015-2025 The Khronos Group Inc.
+ * Copyright (c) 2015-2025 Valve Corporation
+ * Copyright (c) 2015-2025 LunarG, Inc.
  * Copyright (C) 2015-2024 Google Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -20,10 +20,12 @@
 #include "generated/enum_flag_bits.h"
 #include "generated/dispatch_functions.h"
 
-bool StatelessValidation::manual_PreCallValidateAcquireNextImageKHR(VkDevice device, VkSwapchainKHR swapchain, uint64_t timeout,
-                                                                    VkSemaphore semaphore, VkFence fence, uint32_t *pImageIndex,
-                                                                    const ErrorObject &error_obj) const {
+namespace stateless {
+bool Device::manual_PreCallValidateAcquireNextImageKHR(VkDevice device, VkSwapchainKHR swapchain, uint64_t timeout,
+                                                       VkSemaphore semaphore, VkFence fence, uint32_t *pImageIndex,
+                                                       const Context &context) const {
     bool skip = false;
+    const auto &error_obj = context.error_obj;
 
     if (semaphore == VK_NULL_HANDLE && fence == VK_NULL_HANDLE) {
         skip |= LogError("VUID-vkAcquireNextImageKHR-semaphore-01780", swapchain, error_obj.location,
@@ -33,9 +35,10 @@ bool StatelessValidation::manual_PreCallValidateAcquireNextImageKHR(VkDevice dev
     return skip;
 }
 
-bool StatelessValidation::manual_PreCallValidateAcquireNextImage2KHR(VkDevice device, const VkAcquireNextImageInfoKHR *pAcquireInfo,
-                                                                     uint32_t *pImageIndex, const ErrorObject &error_obj) const {
+bool Device::manual_PreCallValidateAcquireNextImage2KHR(VkDevice device, const VkAcquireNextImageInfoKHR *pAcquireInfo,
+                                                        uint32_t *pImageIndex, const Context &context) const {
     bool skip = false;
+    const auto &error_obj = context.error_obj;
 
     if (pAcquireInfo->semaphore == VK_NULL_HANDLE && pAcquireInfo->fence == VK_NULL_HANDLE) {
         skip |= LogError("VUID-VkAcquireNextImageInfoKHR-semaphore-01782", pAcquireInfo->swapchain,
@@ -45,7 +48,49 @@ bool StatelessValidation::manual_PreCallValidateAcquireNextImage2KHR(VkDevice de
     return skip;
 }
 
-bool StatelessValidation::ValidateSwapchainCreateInfo(const VkSwapchainCreateInfoKHR &create_info, const Location &loc) const {
+bool Device::ValidateSwapchainCreateInfoMaintenance1(const VkSwapchainCreateInfoKHR &create_info, const Location &loc) const {
+    bool skip = false;
+
+    if (enabled_features.swapchainMaintenance1) {
+        return skip;
+    }
+
+    if (vku::FindStructInPNextChain<VkSwapchainPresentModesCreateInfoEXT>(create_info.pNext)) {
+        skip |= LogError("VUID-VkSwapchainCreateInfoKHR-swapchainMaintenance1-10155", device, loc.dot(Field::pNext),
+                         "contains VkSwapchainPresentModesCreateInfoEXT, but swapchainMaintenance1 is not enabled");
+    }
+
+    if (const auto *present_scaling_create_info =
+            vku::FindStructInPNextChain<VkSwapchainPresentScalingCreateInfoEXT>(create_info.pNext)) {
+        if (present_scaling_create_info->scalingBehavior != 0) {
+            skip |= LogError("VUID-VkSwapchainPresentScalingCreateInfoEXT-swapchainMaintenance1-10154", device,
+                             loc.pNext(Struct::VkSwapchainPresentScalingCreateInfoEXT, Field::scalingBehavior),
+                             " is %s, but swapchainMaintenance1 is not enabled",
+                             string_VkPresentScalingFlagsEXT(present_scaling_create_info->scalingBehavior).c_str());
+        } else if (present_scaling_create_info->presentGravityX != 0) {
+            skip |= LogError("VUID-VkSwapchainPresentScalingCreateInfoEXT-swapchainMaintenance1-10154", device,
+                             loc.pNext(Struct::VkSwapchainPresentScalingCreateInfoEXT, Field::presentGravityX),
+                             " is %s, but swapchainMaintenance1 is not enabled",
+                             string_VkPresentGravityFlagsEXT(present_scaling_create_info->presentGravityX).c_str());
+        } else if (present_scaling_create_info->presentGravityY != 0) {
+            skip |= LogError("VUID-VkSwapchainPresentScalingCreateInfoEXT-swapchainMaintenance1-10154", device,
+                             loc.pNext(Struct::VkSwapchainPresentScalingCreateInfoEXT, Field::presentGravityY),
+                             " is %s, but swapchainMaintenance1 is not enabled",
+                             string_VkPresentGravityFlagsEXT(present_scaling_create_info->presentGravityY).c_str());
+        }
+    }
+
+    if (create_info.flags & VK_SWAPCHAIN_CREATE_DEFERRED_MEMORY_ALLOCATION_BIT_EXT) {
+        skip |= LogError("VUID-VkSwapchainCreateInfoKHR-swapchainMaintenance1-10157", device, loc.dot(Field::flags),
+                         "is %s, but swapchainMaintenance1 is not enabled",
+                         string_VkSwapchainCreateFlagsKHR(create_info.flags).c_str());
+    }
+
+    return skip;
+}
+
+bool Device::ValidateSwapchainCreateInfo(const Context &context, const VkSwapchainCreateInfoKHR &create_info,
+                                         const Location &loc) const {
     bool skip = false;
 
     // Validation for parameters excluded from the generated validation code due to a 'noautovalidity' tag in vk.xml
@@ -65,8 +110,8 @@ bool StatelessValidation::ValidateSwapchainCreateInfo(const VkSwapchainCreateInf
         }
     }
 
-    skip |= ValidateNotZero(create_info.imageArrayLayers == 0, "VUID-VkSwapchainCreateInfoKHR-imageArrayLayers-01275",
-                            loc.dot(Field::imageArrayLayers));
+    skip |= context.ValidateNotZero(create_info.imageArrayLayers == 0, "VUID-VkSwapchainCreateInfoKHR-imageArrayLayers-01275",
+                                    loc.dot(Field::imageArrayLayers));
 
     // Validate VK_KHR_image_format_list VkImageFormatListCreateInfo
     const auto format_list_info = vku::FindStructInPNextChain<VkImageFormatListCreateInfo>(create_info.pNext);
@@ -127,9 +172,10 @@ bool StatelessValidation::ValidateSwapchainCreateInfo(const VkSwapchainCreateInf
     }
 
     if (create_info.flags & VK_SWAPCHAIN_CREATE_PROTECTED_BIT_KHR) {
-        const bool is_required_ext_supported =
-            SupportedByPdev(physical_device, vvl::Extension::_VK_KHR_surface_protected_capabilities);
-        const bool is_required_ext_enabled = IsExtEnabled(instance_extensions.vk_khr_surface_protected_capabilities);
+        auto stateless_instance = static_cast<Instance *>(dispatch_instance_->GetValidationObject(container_type));
+        const auto &physdev_extensions = stateless_instance->physical_device_extensions.at(physical_device);
+        const bool is_required_ext_supported = IsExtEnabled(physdev_extensions.vk_khr_surface_protected_capabilities);
+        const bool is_required_ext_enabled = IsExtEnabled(extensions.vk_khr_surface_protected_capabilities);
 
         if (is_required_ext_supported && !is_required_ext_enabled) {
             skip |= LogError("VUID-VkSwapchainCreateInfoKHR-flags-03187", device, loc.dot(Field::flags),
@@ -151,34 +197,51 @@ bool StatelessValidation::ValidateSwapchainCreateInfo(const VkSwapchainCreateInf
         }
     }
 
+    skip |= ValidateSwapchainCreateInfoMaintenance1(create_info, loc);
+
     return skip;
 }
 
-bool StatelessValidation::manual_PreCallValidateCreateSwapchainKHR(VkDevice device, const VkSwapchainCreateInfoKHR *pCreateInfo,
-                                                                   const VkAllocationCallbacks *pAllocator,
-                                                                   VkSwapchainKHR *pSwapchain, const ErrorObject &error_obj) const {
+bool Device::manual_PreCallValidateReleaseSwapchainImagesEXT(VkDevice device, const VkReleaseSwapchainImagesInfoEXT *pReleaseInfo,
+                                                             const Context &context) const {
     bool skip = false;
-    skip |= ValidateSwapchainCreateInfo(*pCreateInfo, error_obj.location.dot(Field::pCreateInfo));
+
+    if (!enabled_features.swapchainMaintenance1) {
+        skip |= LogError("VUID-vkReleaseSwapchainImagesEXT-swapchainMaintenance1-10159", device, context.error_obj.location,
+                         "swapchainMaintenance1 is not enabled");
+    }
+
     return skip;
 }
 
-bool StatelessValidation::manual_PreCallValidateCreateSharedSwapchainsKHR(VkDevice device, uint32_t swapchainCount,
-                                                                          const VkSwapchainCreateInfoKHR *pCreateInfos,
-                                                                          const VkAllocationCallbacks *pAllocator,
-                                                                          VkSwapchainKHR *pSwapchains,
-                                                                          const ErrorObject &error_obj) const {
+bool Device::manual_PreCallValidateCreateSwapchainKHR(VkDevice device, const VkSwapchainCreateInfoKHR *pCreateInfo,
+                                                      const VkAllocationCallbacks *pAllocator, VkSwapchainKHR *pSwapchain,
+                                                      const Context &context) const {
     bool skip = false;
+    const auto &error_obj = context.error_obj;
+
+    skip |= ValidateSwapchainCreateInfo(context, *pCreateInfo, error_obj.location.dot(Field::pCreateInfo));
+    return skip;
+}
+
+bool Device::manual_PreCallValidateCreateSharedSwapchainsKHR(VkDevice device, uint32_t swapchainCount,
+                                                             const VkSwapchainCreateInfoKHR *pCreateInfos,
+                                                             const VkAllocationCallbacks *pAllocator, VkSwapchainKHR *pSwapchains,
+                                                             const Context &context) const {
+    bool skip = false;
+    const auto &error_obj = context.error_obj;
     if (pCreateInfos) {
         for (uint32_t i = 0; i < swapchainCount; i++) {
-            skip |= ValidateSwapchainCreateInfo(pCreateInfos[i], error_obj.location.dot(Field::pCreateInfos, i));
+            skip |= ValidateSwapchainCreateInfo(context, pCreateInfos[i], error_obj.location.dot(Field::pCreateInfos, i));
         }
     }
     return skip;
 }
 
-bool StatelessValidation::manual_PreCallValidateQueuePresentKHR(VkQueue queue, const VkPresentInfoKHR *pPresentInfo,
-                                                                const ErrorObject &error_obj) const {
+bool Device::manual_PreCallValidateQueuePresentKHR(VkQueue queue, const VkPresentInfoKHR *pPresentInfo,
+                                                   const Context &context) const {
     bool skip = false;
+    const auto &error_obj = context.error_obj;
     if (!pPresentInfo) return skip;
 
     if (const auto *present_regions = vku::FindStructInPNextChain<VkPresentRegionsKHR>(pPresentInfo->pNext)) {
@@ -191,6 +254,12 @@ bool StatelessValidation::manual_PreCallValidateQueuePresentKHR(VkQueue queue, c
         }
     }
 
+    if (vku::FindStructInPNextChain<VkSwapchainPresentFenceInfoEXT>(pPresentInfo->pNext) &&
+        !enabled_features.swapchainMaintenance1) {
+        skip |= LogError("VUID-VkPresentInfoKHR-swapchainMaintenance1-10158", device, error_obj.location.dot(Field::pNext),
+                         "contains VkSwapchainPresentFenceInfoEXT, but swapchainMaintenance1 is not enabled");
+    }
+
     for (uint32_t i = 0; i < pPresentInfo->swapchainCount; ++i) {
         for (uint32_t j = i + 1; j < pPresentInfo->swapchainCount; ++j) {
             if (pPresentInfo->pSwapchains[i] == pPresentInfo->pSwapchains[j]) {
@@ -204,33 +273,35 @@ bool StatelessValidation::manual_PreCallValidateQueuePresentKHR(VkQueue queue, c
     return skip;
 }
 
-bool StatelessValidation::manual_PreCallValidateCreateDisplayModeKHR(VkPhysicalDevice physicalDevice, VkDisplayKHR display,
-                                                                     const VkDisplayModeCreateInfoKHR *pCreateInfo,
-                                                                     const VkAllocationCallbacks *pAllocator,
-                                                                     VkDisplayModeKHR *pMode, const ErrorObject &error_obj) const {
+bool Instance::manual_PreCallValidateCreateDisplayModeKHR(VkPhysicalDevice physicalDevice, VkDisplayKHR display,
+                                                          const VkDisplayModeCreateInfoKHR *pCreateInfo,
+                                                          const VkAllocationCallbacks *pAllocator, VkDisplayModeKHR *pMode,
+                                                          const Context &context) const {
     bool skip = false;
+    const auto &error_obj = context.error_obj;
 
     const VkDisplayModeParametersKHR display_mode_parameters = pCreateInfo->parameters;
     const Location create_info_loc = error_obj.location.dot(Field::pCreateInfo);
     const Location param_loc = create_info_loc.dot(Field::parameters);
 
-    skip |= ValidateNotZero(display_mode_parameters.visibleRegion.width == 0, "VUID-VkDisplayModeParametersKHR-width-01990",
-                            param_loc.dot(Field::visibleRegion).dot(Field::width));
-    skip |= ValidateNotZero(display_mode_parameters.visibleRegion.height == 0, "VUID-VkDisplayModeParametersKHR-height-01991",
-                            param_loc.dot(Field::visibleRegion).dot(Field::width));
-    skip |= ValidateNotZero(display_mode_parameters.refreshRate == 0, "VUID-VkDisplayModeParametersKHR-refreshRate-01992",
-                            param_loc.dot(Field::refreshRate));
+    skip |= context.ValidateNotZero(display_mode_parameters.visibleRegion.width == 0, "VUID-VkDisplayModeParametersKHR-width-01990",
+                                    param_loc.dot(Field::visibleRegion).dot(Field::width));
+    skip |=
+        context.ValidateNotZero(display_mode_parameters.visibleRegion.height == 0, "VUID-VkDisplayModeParametersKHR-height-01991",
+                                param_loc.dot(Field::visibleRegion).dot(Field::width));
+    skip |= context.ValidateNotZero(display_mode_parameters.refreshRate == 0, "VUID-VkDisplayModeParametersKHR-refreshRate-01992",
+                                    param_loc.dot(Field::refreshRate));
 
     return skip;
 }
 
-bool StatelessValidation::manual_PreCallValidateGetPhysicalDeviceSurfaceFormatsKHR(VkPhysicalDevice physicalDevice,
-                                                                                   VkSurfaceKHR surface,
-                                                                                   uint32_t *pSurfaceFormatCount,
-                                                                                   VkSurfaceFormatKHR *pSurfaceFormats,
-                                                                                   const ErrorObject &error_obj) const {
+bool Instance::manual_PreCallValidateGetPhysicalDeviceSurfaceFormatsKHR(VkPhysicalDevice physicalDevice, VkSurfaceKHR surface,
+                                                                        uint32_t *pSurfaceFormatCount,
+                                                                        VkSurfaceFormatKHR *pSurfaceFormats,
+                                                                        const Context &context) const {
     bool skip = false;
-    if (surface == VK_NULL_HANDLE && !IsExtEnabled(instance_extensions.vk_google_surfaceless_query)) {
+    const auto &error_obj = context.error_obj;
+    if (surface == VK_NULL_HANDLE && !IsExtEnabled(extensions.vk_google_surfaceless_query)) {
         skip |=
             LogError("VUID-vkGetPhysicalDeviceSurfaceFormatsKHR-surface-06524", physicalDevice,
                      error_obj.location.dot(Field::surface), "is VK_NULL_HANDLE and VK_GOOGLE_surfaceless_query is not enabled.");
@@ -238,13 +309,13 @@ bool StatelessValidation::manual_PreCallValidateGetPhysicalDeviceSurfaceFormatsK
     return skip;
 }
 
-bool StatelessValidation::manual_PreCallValidateGetPhysicalDeviceSurfacePresentModesKHR(VkPhysicalDevice physicalDevice,
-                                                                                        VkSurfaceKHR surface,
-                                                                                        uint32_t *pPresentModeCount,
-                                                                                        VkPresentModeKHR *pPresentModes,
-                                                                                        const ErrorObject &error_obj) const {
+bool Instance::manual_PreCallValidateGetPhysicalDeviceSurfacePresentModesKHR(VkPhysicalDevice physicalDevice, VkSurfaceKHR surface,
+                                                                             uint32_t *pPresentModeCount,
+                                                                             VkPresentModeKHR *pPresentModes,
+                                                                             const Context &context) const {
     bool skip = false;
-    if (surface == VK_NULL_HANDLE && !IsExtEnabled(instance_extensions.vk_google_surfaceless_query)) {
+    const auto &error_obj = context.error_obj;
+    if (surface == VK_NULL_HANDLE && !IsExtEnabled(extensions.vk_google_surfaceless_query)) {
         skip |=
             LogError("VUID-vkGetPhysicalDeviceSurfacePresentModesKHR-surface-06524", physicalDevice,
                      error_obj.location.dot(Field::surface), "is VK_NULL_HANDLE and VK_GOOGLE_surfaceless_query is not enabled.");
@@ -252,11 +323,13 @@ bool StatelessValidation::manual_PreCallValidateGetPhysicalDeviceSurfacePresentM
     return skip;
 }
 
-bool StatelessValidation::manual_PreCallValidateGetPhysicalDeviceSurfaceCapabilities2KHR(
-    VkPhysicalDevice physicalDevice, const VkPhysicalDeviceSurfaceInfo2KHR *pSurfaceInfo,
-    VkSurfaceCapabilities2KHR *pSurfaceCapabilities, const ErrorObject &error_obj) const {
+bool Instance::manual_PreCallValidateGetPhysicalDeviceSurfaceCapabilities2KHR(VkPhysicalDevice physicalDevice,
+                                                                              const VkPhysicalDeviceSurfaceInfo2KHR *pSurfaceInfo,
+                                                                              VkSurfaceCapabilities2KHR *pSurfaceCapabilities,
+                                                                              const Context &context) const {
     bool skip = false;
-    if (pSurfaceInfo && pSurfaceInfo->surface == VK_NULL_HANDLE && !IsExtEnabled(instance_extensions.vk_google_surfaceless_query)) {
+    const auto &error_obj = context.error_obj;
+    if (pSurfaceInfo && pSurfaceInfo->surface == VK_NULL_HANDLE && !IsExtEnabled(extensions.vk_google_surfaceless_query)) {
         skip |= LogError("VUID-vkGetPhysicalDeviceSurfaceCapabilities2KHR-pSurfaceInfo-06521", physicalDevice,
                          error_obj.location.dot(Field::pSurfaceInfo).dot(Field::surface),
                          "is VK_NULL_HANDLE and VK_GOOGLE_surfaceless_query is not enabled.");
@@ -311,21 +384,26 @@ bool StatelessValidation::manual_PreCallValidateGetPhysicalDeviceSurfaceCapabili
     return skip;
 }
 
-bool StatelessValidation::manual_PreCallValidateGetPhysicalDeviceSurfaceFormats2KHR(
-    VkPhysicalDevice physicalDevice, const VkPhysicalDeviceSurfaceInfo2KHR *pSurfaceInfo, uint32_t *pSurfaceFormatCount,
-    VkSurfaceFormat2KHR *pSurfaceFormats, const ErrorObject &error_obj) const {
+bool Instance::manual_PreCallValidateGetPhysicalDeviceSurfaceFormats2KHR(VkPhysicalDevice physicalDevice,
+                                                                         const VkPhysicalDeviceSurfaceInfo2KHR *pSurfaceInfo,
+                                                                         uint32_t *pSurfaceFormatCount,
+                                                                         VkSurfaceFormat2KHR *pSurfaceFormats,
+                                                                         const Context &context) const {
     bool skip = false;
-    if (pSurfaceInfo && pSurfaceInfo->surface == VK_NULL_HANDLE && !IsExtEnabled(instance_extensions.vk_google_surfaceless_query)) {
+    const auto &error_obj = context.error_obj;
+    if (pSurfaceInfo && pSurfaceInfo->surface == VK_NULL_HANDLE && !IsExtEnabled(extensions.vk_google_surfaceless_query)) {
         skip |= LogError("VUID-vkGetPhysicalDeviceSurfaceFormats2KHR-pSurfaceInfo-06521", physicalDevice,
                          error_obj.location.dot(Field::pSurfaceInfo).dot(Field::surface),
                          "is VK_NULL_HANDLE and VK_GOOGLE_surfaceless_query is not enabled.");
     }
     if (pSurfaceFormats) {
-        for (uint32_t i = 0; i < *pSurfaceFormatCount; ++i) {
-            if (vku::FindStructInPNextChain<VkImageCompressionPropertiesEXT>(pSurfaceFormats[i].pNext) &&
-                !enabled_features.imageCompressionControlSwapchain) {
-                skip |= LogError("VUID-VkSurfaceFormat2KHR-pNext-06750", device, error_obj.location.dot(Field::pNext),
-                                 "contains VkImageCompressionPropertiesEXT, but imageCompressionControlSwapchain is not enabled");
+        if (vku::FindStructInPNextChain<VkImageCompressionPropertiesEXT>(pSurfaceFormats->pNext)) {
+            const auto &physdev_extensions = physical_device_extensions.at(physicalDevice);
+            if (!IsExtEnabled(physdev_extensions.vk_ext_image_compression_control_swapchain)) {
+                skip |= LogError("VUID-VkSurfaceFormat2KHR-pNext-06750", physicalDevice,
+                                 error_obj.location.dot(Field::pSurfaceFormats).dot(Field::pNext),
+                                 "contains a VkImageCompressionPropertiesEXT struct but VK_EXT_image_compression_control_swapchain "
+                                 "is not supported.");
             }
         }
     }
@@ -333,11 +411,14 @@ bool StatelessValidation::manual_PreCallValidateGetPhysicalDeviceSurfaceFormats2
 }
 
 #ifdef VK_USE_PLATFORM_WIN32_KHR
-bool StatelessValidation::manual_PreCallValidateGetPhysicalDeviceSurfacePresentModes2EXT(
-    VkPhysicalDevice physicalDevice, const VkPhysicalDeviceSurfaceInfo2KHR *pSurfaceInfo, uint32_t *pPresentModeCount,
-    VkPresentModeKHR *pPresentModes, const ErrorObject &error_obj) const {
+bool Instance::manual_PreCallValidateGetPhysicalDeviceSurfacePresentModes2EXT(VkPhysicalDevice physicalDevice,
+                                                                              const VkPhysicalDeviceSurfaceInfo2KHR *pSurfaceInfo,
+                                                                              uint32_t *pPresentModeCount,
+                                                                              VkPresentModeKHR *pPresentModes,
+                                                                              const Context &context) const {
     bool skip = false;
-    if (pSurfaceInfo && pSurfaceInfo->surface == VK_NULL_HANDLE && !IsExtEnabled(instance_extensions.vk_google_surfaceless_query)) {
+    const auto &error_obj = context.error_obj;
+    if (pSurfaceInfo && pSurfaceInfo->surface == VK_NULL_HANDLE && !IsExtEnabled(extensions.vk_google_surfaceless_query)) {
         skip |= LogError("VUID-vkGetPhysicalDeviceSurfacePresentModes2EXT-pSurfaceInfo-06521", physicalDevice,
                          error_obj.location.dot(Field::pSurfaceInfo).dot(Field::surface),
                          "is VK_NULL_HANDLE and VK_GOOGLE_surfaceless_query is not enabled.");
@@ -345,11 +426,11 @@ bool StatelessValidation::manual_PreCallValidateGetPhysicalDeviceSurfacePresentM
     return skip;
 }
 
-bool StatelessValidation::manual_PreCallValidateCreateWin32SurfaceKHR(VkInstance instance,
-                                                                      const VkWin32SurfaceCreateInfoKHR *pCreateInfo,
-                                                                      const VkAllocationCallbacks *pAllocator,
-                                                                      VkSurfaceKHR *pSurface, const ErrorObject &error_obj) const {
+bool Instance::manual_PreCallValidateCreateWin32SurfaceKHR(VkInstance instance, const VkWin32SurfaceCreateInfoKHR *pCreateInfo,
+                                                           const VkAllocationCallbacks *pAllocator, VkSurfaceKHR *pSurface,
+                                                           const Context &context) const {
     bool skip = false;
+    const auto &error_obj = context.error_obj;
 
     if (pCreateInfo->hwnd == nullptr) {
         skip |= LogError("VUID-VkWin32SurfaceCreateInfoKHR-hwnd-01308", instance, error_obj.location, "pCreateInfo->hwnd is NULL.");
@@ -358,27 +439,28 @@ bool StatelessValidation::manual_PreCallValidateCreateWin32SurfaceKHR(VkInstance
     return skip;
 }
 
-bool StatelessValidation::PreCallValidateGetDeviceGroupSurfacePresentModes2EXT(VkDevice device,
-                                                                               const VkPhysicalDeviceSurfaceInfo2KHR *pSurfaceInfo,
-                                                                               VkDeviceGroupPresentModeFlagsKHR *pModes,
-                                                                               const ErrorObject &error_obj) const {
+bool Device::PreCallValidateGetDeviceGroupSurfacePresentModes2EXT(VkDevice device,
+                                                                  const VkPhysicalDeviceSurfaceInfo2KHR *pSurfaceInfo,
+                                                                  VkDeviceGroupPresentModeFlagsKHR *pModes,
+                                                                  const ErrorObject &error_obj) const {
     bool skip = false;
-    if (!IsExtEnabled(device_extensions.vk_khr_swapchain))
+    Context context(*this, error_obj, extensions);
+    if (!IsExtEnabled(extensions.vk_khr_swapchain))
         skip |= OutputExtensionError(error_obj.location, {vvl::Extension::_VK_KHR_swapchain});
-    if (!IsExtEnabled(device_extensions.vk_khr_get_surface_capabilities2))
+    if (!IsExtEnabled(extensions.vk_khr_get_surface_capabilities2))
         skip |= OutputExtensionError(error_obj.location, {vvl::Extension::_VK_KHR_get_surface_capabilities2});
-    if (!IsExtEnabled(device_extensions.vk_khr_surface))
+    if (!IsExtEnabled(extensions.vk_khr_surface))
         skip |= OutputExtensionError(error_obj.location, {vvl::Extension::_VK_KHR_surface});
-    if (!IsExtEnabled(device_extensions.vk_khr_get_physical_device_properties2))
+    if (!IsExtEnabled(extensions.vk_khr_get_physical_device_properties2))
         skip |= OutputExtensionError(error_obj.location, {vvl::Extension::_VK_KHR_get_physical_device_properties2});
-    if (!IsExtEnabled(device_extensions.vk_ext_full_screen_exclusive))
+    if (!IsExtEnabled(extensions.vk_ext_full_screen_exclusive))
         skip |= OutputExtensionError(error_obj.location, {vvl::Extension::_VK_EXT_full_screen_exclusive});
     if (!pModes) {
         skip |= LogError("VUID-vkGetDeviceGroupSurfacePresentModes2EXT-pModes-parameter", device,
                          error_obj.location.dot(Field::pModes), "is NULL.");
     }
 
-    skip |= ValidateStructType(
+    skip |= context.ValidateStructType(
         error_obj.location.dot(Field::pSurfaceInfo), pSurfaceInfo, VK_STRUCTURE_TYPE_PHYSICAL_DEVICE_SURFACE_INFO_2_KHR, true,
         "VUID-vkGetDeviceGroupSurfacePresentModes2EXT-pSurfaceInfo-parameter", "VUID-VkPhysicalDeviceSurfaceInfo2KHR-sType-sType");
     if (pSurfaceInfo != NULL) {
@@ -386,30 +468,30 @@ bool StatelessValidation::PreCallValidateGetDeviceGroupSurfacePresentModes2EXT(V
                                                 VK_STRUCTURE_TYPE_SURFACE_FULL_SCREEN_EXCLUSIVE_WIN32_INFO_EXT,
                                                 VK_STRUCTURE_TYPE_SURFACE_PRESENT_MODE_EXT};
 
-        skip |= ValidateStructPnext(error_obj.location.dot(Field::pSurfaceInfo), pSurfaceInfo->pNext, allowed_structs.size(),
-                                    allowed_structs.data(), GeneratedVulkanHeaderVersion,
-                                    "VUID-VkPhysicalDeviceSurfaceInfo2KHR-pNext-pNext",
-                                    "VUID-VkPhysicalDeviceSurfaceInfo2KHR-sType-unique");
+        skip |= context.ValidateStructPnext(error_obj.location.dot(Field::pSurfaceInfo), pSurfaceInfo->pNext,
+                                            allowed_structs.size(), allowed_structs.data(), GeneratedVulkanHeaderVersion,
+                                            "VUID-VkPhysicalDeviceSurfaceInfo2KHR-pNext-pNext",
+                                            "VUID-VkPhysicalDeviceSurfaceInfo2KHR-sType-unique");
 
-        if (pSurfaceInfo->surface == VK_NULL_HANDLE && !IsExtEnabled(instance_extensions.vk_google_surfaceless_query)) {
+        if (pSurfaceInfo->surface == VK_NULL_HANDLE && !IsExtEnabled(extensions.vk_google_surfaceless_query)) {
             skip |= LogError("VUID-vkGetPhysicalDeviceSurfacePresentModes2EXT-pSurfaceInfo-06521", device,
                              error_obj.location.dot(Field::pSurfaceInfo).dot(Field::surface),
                              "is VK_NULL_HANDLE and VK_GOOGLE_surfaceless_query is not enabled.");
         }
 
-        skip |= ValidateRequiredHandle(error_obj.location.dot(Field::pSurfaceInfo).dot(Field::surface), pSurfaceInfo->surface);
+        skip |=
+            context.ValidateRequiredHandle(error_obj.location.dot(Field::pSurfaceInfo).dot(Field::surface), pSurfaceInfo->surface);
     }
     return skip;
 }
 #endif  // VK_USE_PLATFORM_WIN32_KHR
 
 #ifdef VK_USE_PLATFORM_WAYLAND_KHR
-bool StatelessValidation::manual_PreCallValidateCreateWaylandSurfaceKHR(VkInstance instance,
-                                                                        const VkWaylandSurfaceCreateInfoKHR *pCreateInfo,
-                                                                        const VkAllocationCallbacks *pAllocator,
-                                                                        VkSurfaceKHR *pSurface,
-                                                                        const ErrorObject &error_obj) const {
+bool Instance::manual_PreCallValidateCreateWaylandSurfaceKHR(VkInstance instance, const VkWaylandSurfaceCreateInfoKHR *pCreateInfo,
+                                                             const VkAllocationCallbacks *pAllocator, VkSurfaceKHR *pSurface,
+                                                             const Context &context) const {
     bool skip = false;
+    const auto &error_obj = context.error_obj;
 
     const auto display = pCreateInfo->display;
     const auto surface = pCreateInfo->surface;
@@ -429,11 +511,11 @@ bool StatelessValidation::manual_PreCallValidateCreateWaylandSurfaceKHR(VkInstan
 #endif  // VK_USE_PLATFORM_WAYLAND_KHR
 
 #ifdef VK_USE_PLATFORM_XCB_KHR
-bool StatelessValidation::manual_PreCallValidateCreateXcbSurfaceKHR(VkInstance instance,
-                                                                    const VkXcbSurfaceCreateInfoKHR *pCreateInfo,
-                                                                    const VkAllocationCallbacks *pAllocator, VkSurfaceKHR *pSurface,
-                                                                    const ErrorObject &error_obj) const {
+bool Instance::manual_PreCallValidateCreateXcbSurfaceKHR(VkInstance instance, const VkXcbSurfaceCreateInfoKHR *pCreateInfo,
+                                                         const VkAllocationCallbacks *pAllocator, VkSurfaceKHR *pSurface,
+                                                         const Context &context) const {
     bool skip = false;
+    const auto &error_obj = context.error_obj;
 
     const auto connection = pCreateInfo->connection;
     const auto window = pCreateInfo->window;
@@ -443,19 +525,19 @@ bool StatelessValidation::manual_PreCallValidateCreateXcbSurfaceKHR(VkInstance i
                          error_obj.location.dot(Field::pCreateInfo).dot(Field::connection), "is NULL!");
     }
 
-    skip |= ValidateNotZero(window == 0, "VUID-VkXcbSurfaceCreateInfoKHR-window-01311",
-                            error_obj.location.dot(Field::pCreateInfo).dot(Field::window));
+    skip |= context.ValidateNotZero(window == 0, "VUID-VkXcbSurfaceCreateInfoKHR-window-01311",
+                                    error_obj.location.dot(Field::pCreateInfo).dot(Field::window));
 
     return skip;
 }
 #endif  // VK_USE_PLATFORM_XCB_KHR
 
 #ifdef VK_USE_PLATFORM_XLIB_KHR
-bool StatelessValidation::manual_PreCallValidateCreateXlibSurfaceKHR(VkInstance instance,
-                                                                     const VkXlibSurfaceCreateInfoKHR *pCreateInfo,
-                                                                     const VkAllocationCallbacks *pAllocator,
-                                                                     VkSurfaceKHR *pSurface, const ErrorObject &error_obj) const {
+bool Instance::manual_PreCallValidateCreateXlibSurfaceKHR(VkInstance instance, const VkXlibSurfaceCreateInfoKHR *pCreateInfo,
+                                                          const VkAllocationCallbacks *pAllocator, VkSurfaceKHR *pSurface,
+                                                          const Context &context) const {
     bool skip = false;
+    const auto &error_obj = context.error_obj;
 
     const auto display = pCreateInfo->dpy;
     const auto window = pCreateInfo->window;
@@ -465,20 +547,19 @@ bool StatelessValidation::manual_PreCallValidateCreateXlibSurfaceKHR(VkInstance
                          error_obj.location.dot(Field::pCreateInfo).dot(Field::dpy), "is NULL!");
     }
 
-    skip |= ValidateNotZero(window == 0, "VUID-VkXlibSurfaceCreateInfoKHR-window-01314",
-                            error_obj.location.dot(Field::pCreateInfo).dot(Field::window));
+    skip |= context.ValidateNotZero(window == 0, "VUID-VkXlibSurfaceCreateInfoKHR-window-01314",
+                                    error_obj.location.dot(Field::pCreateInfo).dot(Field::window));
 
     return skip;
 }
 #endif  // VK_USE_PLATFORM_XLIB_KHR
 
 #ifdef VK_USE_PLATFORM_ANDROID_KHR
-bool StatelessValidation::manual_PreCallValidateCreateAndroidSurfaceKHR(VkInstance instance,
-                                                                        const VkAndroidSurfaceCreateInfoKHR *pCreateInfo,
-                                                                        const VkAllocationCallbacks *pAllocator,
-                                                                        VkSurfaceKHR *pSurface,
-                                                                        const ErrorObject &error_obj) const {
+bool Instance::manual_PreCallValidateCreateAndroidSurfaceKHR(VkInstance instance, const VkAndroidSurfaceCreateInfoKHR *pCreateInfo,
+                                                             const VkAllocationCallbacks *pAllocator, VkSurfaceKHR *pSurface,
+                                                             const Context &context) const {
     bool skip = false;
+    const auto &error_obj = context.error_obj;
     if (pCreateInfo->window == nullptr) {
         skip |= LogError("VUID-VkAndroidSurfaceCreateInfoKHR-window-01248", instance,
                          error_obj.location.dot(Field::pCreateInfo).dot(Field::window), "is NULL.");
@@ -486,3 +567,4 @@ bool StatelessValidation::manual_PreCallValidateCreateAndroidSurfaceKHR(VkInstan
     return skip;
 }
 #endif  // VK_USE_PLATFORM_ANDROID_KHR
+}  // namespace stateless
