@@ -1,6 +1,6 @@
-/* Copyright (c) 2015-2017, 2019-2024 The Khronos Group Inc.
- * Copyright (c) 2015-2017, 2019-2024 Valve Corporation
- * Copyright (c) 2015-2017, 2019-2024 LunarG, Inc.
+/* Copyright (c) 2015-2017, 2019-2025 The Khronos Group Inc.
+ * Copyright (c) 2015-2017, 2019-2025 Valve Corporation
+ * Copyright (c) 2015-2017, 2019-2025 LunarG, Inc.
  * Modifications Copyright (C) 2022 RasterGrid Kft.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -20,31 +20,23 @@
 
 #include <algorithm>
 #include <atomic>
-#include <bitset>
 #include <cassert>
 #include <cctype>
 #include <cmath>
 #include <cstring>
 #include <memory>
-#include <optional>
 #include <shared_mutex>
 #include <string>
-#include <type_traits>
 #include <vector>
 
 #include <vulkan/utility/vk_format_utils.h>
 #include <vulkan/utility/vk_concurrent_unordered_map.hpp>
 #include <vulkan/utility/vk_struct_helper.hpp>
 #include "vulkan/vk_layer.h"
+#include "utils/math_utils.h"
 
 #include "generated/vk_layer_dispatch_table.h"
 
-#ifndef WIN32
-#include <strings.h>  // For ffs()
-#else
-#include <intrin.h>  // For __lzcnt()
-#endif
-
 #define STRINGIFY(s) STRINGIFY_HELPER(s)
 #define STRINGIFY_HELPER(s) #s
 
@@ -103,64 +95,6 @@ static inline dispatch_key GetDispatchKey(const void *object) { return (dispatch
 VkLayerInstanceCreateInfo *GetChainInfo(const VkInstanceCreateInfo *pCreateInfo, VkLayerFunction func);
 VkLayerDeviceCreateInfo *GetChainInfo(const VkDeviceCreateInfo *pCreateInfo, VkLayerFunction func);
 
-template <typename T>
-constexpr bool IsPowerOfTwo(T x) {
-    static_assert(std::numeric_limits<T>::is_integer, "Unsigned integer required.");
-    static_assert(std::is_unsigned<T>::value, "Unsigned integer required.");
-    return x && !(x & (x - 1));
-}
-
-// Returns the 0-based index of the MSB, like the x86 bit scan reverse (bsr) instruction
-// Note: an input mask of 0 yields -1
-static inline int MostSignificantBit(uint32_t mask) {
-#if defined __GNUC__
-    return mask ? __builtin_clz(mask) ^ 31 : -1;
-#elif defined _MSC_VER
-    unsigned long bit_pos;
-    return _BitScanReverse(&bit_pos, mask) ? int(bit_pos) : -1;
-#else
-    for (int k = 31; k >= 0; --k) {
-        if (((mask >> k) & 1) != 0) {
-            return k;
-        }
-    }
-    return -1;
-#endif
-}
-
-static inline int u_ffs(int val) {
-#ifdef WIN32
-    unsigned long bit_pos = 0;
-    if (_BitScanForward(&bit_pos, val) != 0) {
-        bit_pos += 1;
-    }
-    return bit_pos;
-#else
-    return ffs(val);
-#endif
-}
-
-// Given p2 a power of two, returns smallest multiple of p2 greater than or equal to x
-// Different than std::align in that it simply aligns an unsigned integer, when std::align aligns a virtual address and does the
-// necessary bookkeeping to be able to correctly free memory at the new address
-template <typename T>
-constexpr T Align(T x, T p2) {
-    static_assert(std::numeric_limits<T>::is_integer, "Unsigned integer required.");
-    static_assert(std::is_unsigned<T>::value, "Unsigned integer required.");
-    assert(IsPowerOfTwo(p2));
-    return (x + p2 - 1) & ~(p2 - 1);
-}
-
-// Returns the 0-based index of the LSB. An input mask of 0 yields -1
-static inline int LeastSignificantBit(uint32_t mask) { return u_ffs(static_cast<int>(mask)) - 1; }
-
-template <typename FlagBits, typename Flags>
-FlagBits LeastSignificantFlag(Flags flags) {
-    const int bit_shift = LeastSignificantBit(flags);
-    assert(bit_shift != -1);
-    return static_cast<FlagBits>(1ull << bit_shift);
-}
-
 // Iterates over all set bits and calls the callback with a bit mask corresponding to each flag.
 // FlagBits and Flags follow Vulkan naming convensions for flag types.
 // An example of a more efficient implementation: https://lemire.me/blog/2018/02/21/iterating-over-set-bits-quickly/
@@ -332,6 +266,24 @@ static inline bool IsAnyPlaneAspect(VkImageAspectFlags aspect_mask) {
     return (aspect_mask & valid_planes) != 0;
 }
 
+static inline uint32_t GetVertexInputFormatSize(VkFormat format) {
+    // Vertex input attributes use VkFormat, but only to make use of how they define sizes, things such as
+    // depth/multi-plane/compressed will never be used here because they would mean nothing. So we can ensure these are "standard"
+    // color formats being used. This function is a wrapper to make it more clear of the intent.
+    return vkuFormatTexelBlockSize(format);
+}
+
+static inline uint32_t GetTexelBufferFormatSize(VkFormat format) {
+    // The spec says "If format is a block-compressed format, then bufferFeatures must not support any features for the format"
+    // For Texel Buffers, we can assume the texel blocks are a 1x1x1 extent
+    // See https://gitlab.khronos.org/vulkan/vulkan/-/issues/4155 for more details
+    return vkuFormatTexelBlockSize(format);
+}
+
+bool AreFormatsSizeCompatible(VkFormat a, VkFormat b,
+                              VkImageAspectFlags aspect_mask = VK_IMAGE_ASPECT_STENCIL_BIT | VK_IMAGE_ASPECT_DEPTH_BIT);
+std::string DescribeFormatsSizeCompatible(VkFormat a, VkFormat b);
+
 static const VkShaderStageFlags kShaderStageAllGraphics =
     VK_SHADER_STAGE_VERTEX_BIT | VK_SHADER_STAGE_TESSELLATION_CONTROL_BIT | VK_SHADER_STAGE_TESSELLATION_EVALUATION_BIT |
     VK_SHADER_STAGE_GEOMETRY_BIT | VK_SHADER_STAGE_FRAGMENT_BIT | VK_SHADER_STAGE_TASK_BIT_EXT | VK_SHADER_STAGE_MESH_BIT_EXT;
@@ -405,12 +357,6 @@ static inline VkDeviceSize SafeDivision(VkDeviceSize dividend, VkDeviceSize divi
     return result;
 }
 
-// Only 32 bit fields should need a bit count
-static inline uint32_t GetBitSetCount(uint32_t field) {
-    std::bitset<32> view_bits(field);
-    return static_cast<uint32_t>(view_bits.count());
-}
-
 static inline uint32_t FullMipChainLevels(VkExtent3D extent) {
     // uint cast applies floor()
     return 1u + static_cast<uint32_t>(log2(std::max({extent.height, extent.width, extent.depth})));
@@ -461,7 +407,7 @@ typedef VkFlags VkStringErrorFlags;
 std::string GetTempFilePath();
 
 // Aliases to avoid excessive typing. We can't easily auto these away because
-// there are virtual methods in ValidationObject which return lock guards
+// there are virtual methods in vvl::base::Device which return lock guards
 // and those cannot use return type deduction.
 typedef std::shared_lock<std::shared_mutex> ReadLockGuard;
 typedef std::unique_lock<std::shared_mutex> WriteLockGuard;
@@ -501,18 +447,6 @@ bool RangesIntersect(int64_t x, uint64_t x_size, int64_t y, uint64_t y_size);
 
 namespace vvl {
 
-static inline void ToLower(std::string &str) {
-    // std::tolower() returns int which can cause compiler warnings
-    transform(str.begin(), str.end(), str.begin(),
-              [](char c) { return static_cast<char>(std::tolower(c)); });
-}
-
-static inline void ToUpper(std::string &str) {
-    // std::toupper() returns int which can cause compiler warnings
-    transform(str.begin(), str.end(), str.begin(),
-              [](char c) { return static_cast<char>(std::toupper(c)); });
-}
-
 // The standard does not specify the value of data() for zero-sized contatiners as being null or non-null,
 // only that it is not dereferenceable.
 //
