@@ -190,7 +190,7 @@ extern const uint32_t {name}[];
         print(source, end="", file=f)
 
 def main():
-    parser = argparse.ArgumentParser(description='Generate spirv code for this repository, see layers/gpu/shaders/README.md for more deatils')
+    parser = argparse.ArgumentParser(description='Generate spirv code for this repository, see layers/gpuav/shaders/README.md for more deatils')
     parser.add_argument('--api',
                         default='vulkan',
                         choices=['vulkan'],
@@ -203,15 +203,15 @@ def main():
     args = parser.parse_args()
 
     shaders_to_compile = []
-    # Get all shaders in gpu/shaders folder
+    # Get all shaders in gpuav/shaders folder
     shader_type = ['vert', 'tesc', 'tese', 'geom', 'frag', 'comp', 'mesh', 'task', 'rgen', 'rint', 'rahit', 'rchit', 'rmiss', 'rcall']
-    gpu_shaders_dir = common_ci.RepoRelative('layers/gpu/shaders')
-    diagnostic_shaders = common_ci.RepoRelative('layers/gpu/shaders/cmd_validation')
+    gpu_shaders_dir = common_ci.RepoRelative('layers/gpuav/shaders')
+    diagnostic_shaders = common_ci.RepoRelative('layers/gpuav/shaders/validation_cmd')
     for filename in os.listdir(diagnostic_shaders):
         if (filename.split(".")[-1] in shader_type):
             shaders_to_compile.append(os.path.join(diagnostic_shaders, filename))
 
-    instrumentation_shaders = common_ci.RepoRelative('layers/gpu/shaders/instrumentation')
+    instrumentation_shaders = common_ci.RepoRelative('layers/gpuav/shaders/instrumentation')
     for filename in os.listdir(instrumentation_shaders):
         if (filename.split(".")[-1] in shader_type):
             shaders_to_compile.append(os.path.join(instrumentation_shaders, filename))
