@@ -1,8 +1,8 @@
 /*
- * Copyright (c) 2015-2023 The Khronos Group Inc.
- * Copyright (c) 2015-2023 Valve Corporation
- * Copyright (c) 2015-2023 LunarG, Inc.
- * Copyright (C) 2015-2023 Google Inc.
+ * Copyright (c) 2015-2024 The Khronos Group Inc.
+ * Copyright (c) 2015-2024 Valve Corporation
+ * Copyright (c) 2015-2024 LunarG, Inc.
+ * Copyright (C) 2015-2024 Google Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -26,6 +26,7 @@
 #include "generated/vk_dispatch_table_helper.h"
 #include "utils/vk_layer_utils.h"
 #include "vk_lunarg_device_profile_api_layer.h"
+#include <vulkan/utility/vk_struct_helper.hpp>
 
 namespace device_profile_api {
 
@@ -49,6 +50,32 @@ struct layer_data {
 
 static std::unordered_map<void *, layer_data *> device_profile_api_dev_data_map;
 
+// For the given data key, look up the layer_data instance from given layer_data_map
+template <typename DATA_T>
+DATA_T *GetLayerDataPtr(void *data_key, std::unordered_map<void *, DATA_T *> &layer_data_map) {
+    DATA_T *debug_data;
+    /* TODO: We probably should lock here, or have caller lock */
+    auto got = layer_data_map.find(data_key);
+
+    if (got == layer_data_map.end()) {
+        debug_data = new DATA_T;
+        layer_data_map[(void *)data_key] = debug_data;
+    } else {
+        debug_data = got->second;
+    }
+
+    return debug_data;
+}
+
+template <typename DATA_T>
+void FreeLayerDataPtr(void *data_key, std::unordered_map<void *, DATA_T *> &layer_data_map) {
+    auto got = layer_data_map.find(data_key);
+    assert(got != layer_data_map.end());
+
+    delete got->second;
+    layer_data_map.erase(got);
+}
+
 // device_profile_api Layer EXT APIs
 typedef void(VKAPI_PTR *PFN_vkGetOriginalPhysicalDeviceLimitsEXT)(VkPhysicalDevice physicalDevice,
                                                                   const VkPhysicalDeviceLimits *limits);
@@ -167,7 +194,7 @@ VKAPI_ATTR void VKAPI_CALL SetPhysicalDeviceProperties2EXT(VkPhysicalDevice phys
 
 VKAPI_ATTR VkResult VKAPI_CALL CreateInstance(const VkInstanceCreateInfo *pCreateInfo, const VkAllocationCallbacks *pAllocator,
                                               VkInstance *pInstance) {
-    VkLayerInstanceCreateInfo *chain_info = get_chain_info(pCreateInfo, VK_LAYER_LINK_INFO);
+    VkLayerInstanceCreateInfo *chain_info = GetChainInfo(pCreateInfo, VK_LAYER_LINK_INFO);
     std::lock_guard<std::mutex> lock(global_lock);
 
     assert(chain_info->u.pLayerInfo);
