@@ -1,8 +1,8 @@
 /*
- * Copyright (c) 2015-2024 The Khronos Group Inc.
- * Copyright (c) 2015-2024 Valve Corporation
- * Copyright (c) 2015-2024 LunarG, Inc.
- * Copyright (c) 2015-2024 Google, Inc.
+ * Copyright (c) 2015-2025 The Khronos Group Inc.
+ * Copyright (c) 2015-2025 Valve Corporation
+ * Copyright (c) 2015-2025 LunarG, Inc.
+ * Copyright (c) 2015-2025 Google, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -30,7 +30,10 @@ TEST_F(PositiveAndroidHardwareBuffer, MemoryRequirements) {
     VkExternalMemoryBufferCreateInfo ext_buf_info = vku::InitStructHelper();
     ext_buf_info.handleTypes = VK_EXTERNAL_MEMORY_HANDLE_TYPE_ANDROID_HARDWARE_BUFFER_BIT_ANDROID;
 
-    VkImportAndroidHardwareBufferInfoANDROID import_ahb_Info = vku::InitStructHelper();
+    VkMemoryDedicatedAllocateInfo memory_dedicated_info = vku::InitStructHelper();
+    memory_dedicated_info.image = VK_NULL_HANDLE;
+
+    VkImportAndroidHardwareBufferInfoANDROID import_ahb_Info = vku::InitStructHelper(&memory_dedicated_info);
     import_ahb_Info.buffer = ahb.handle();
 
     VkAndroidHardwareBufferPropertiesANDROID ahb_props = vku::InitStructHelper();
@@ -45,6 +48,7 @@ TEST_F(PositiveAndroidHardwareBuffer, MemoryRequirements) {
     buffer_create_info.size = memory_allocate_info.allocationSize;
     buffer_create_info.usage = VK_BUFFER_USAGE_UNIFORM_BUFFER_BIT;
     vkt::Buffer buffer(*m_device, buffer_create_info, vkt::no_mem);
+    memory_dedicated_info.buffer = buffer;
 
     // Should be able to bind memory with no error
     vkt::DeviceMemory memory(*m_device, memory_allocate_info);
@@ -143,7 +147,11 @@ TEST_F(PositiveAndroidHardwareBuffer, BindBufferMemory) {
     VkAndroidHardwareBufferPropertiesANDROID ahb_props = vku::InitStructHelper();
     vk::GetAndroidHardwareBufferPropertiesANDROID(device(), ahb.handle(), &ahb_props);
 
-    VkImportAndroidHardwareBufferInfoANDROID import_ahb_Info = vku::InitStructHelper();
+    VkMemoryDedicatedAllocateInfo memory_dedicated_info = vku::InitStructHelper();
+    memory_dedicated_info.image = VK_NULL_HANDLE;
+    memory_dedicated_info.buffer = buffer;
+
+    VkImportAndroidHardwareBufferInfoANDROID import_ahb_Info = vku::InitStructHelper(&memory_dedicated_info);
     import_ahb_Info.buffer = ahb.handle();
 
     VkMemoryAllocateInfo memory_allocate_info = vku::InitStructHelper(&import_ahb_Info);
@@ -174,7 +182,11 @@ TEST_F(PositiveAndroidHardwareBuffer, ExportBuffer) {
     VkMemoryRequirements mem_reqs;
     vk::GetBufferMemoryRequirements(device(), buffer.handle(), &mem_reqs);
 
-    VkExportMemoryAllocateInfo export_memory_info = vku::InitStructHelper();
+    VkMemoryDedicatedAllocateInfo memory_dedicated_info = vku::InitStructHelper();
+    memory_dedicated_info.image = VK_NULL_HANDLE;
+    memory_dedicated_info.buffer = buffer;
+
+    VkExportMemoryAllocateInfo export_memory_info = vku::InitStructHelper(&memory_dedicated_info);
     export_memory_info.handleTypes = VK_EXTERNAL_MEMORY_HANDLE_TYPE_ANDROID_HARDWARE_BUFFER_BIT_ANDROID;
 
     VkMemoryAllocateInfo memory_info = vku::InitStructHelper(&export_memory_info);
