@@ -19,7 +19,7 @@
 #include "../framework/pipeline_helper.h"
 #include "../framework/descriptor_helper.h"
 #include "../framework/ray_tracing_objects.h"
-#include "../../layers/gpu/shaders/gpuav_shaders_constants.h"
+#include "../../layers/gpuav/shaders/gpuav_shaders_constants.h"
 
 class NegativeGpuAVRayQuery : public GpuAVRayQueryTest {};
 
