@@ -1,8 +1,8 @@
 /*
- * Copyright (c) 2015-2023 The Khronos Group Inc.
- * Copyright (c) 2015-2023 Valve Corporation
- * Copyright (c) 2015-2023 LunarG, Inc.
- * Copyright (c) 2015-2023 Google, Inc.
+ * Copyright (c) 2015-2024 The Khronos Group Inc.
+ * Copyright (c) 2015-2024 Valve Corporation
+ * Copyright (c) 2015-2024 LunarG, Inc.
+ * Copyright (c) 2015-2024 Google, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -14,6 +14,8 @@
 #include "../framework/layer_validation_tests.h"
 #include "../framework/pipeline_helper.h"
 
+class PositivePipelineTopology : public VkLayerTest {};
+
 TEST_F(PositivePipelineTopology, PointSizeWriteInFunction) {
     TEST_DESCRIPTION("Create a pipeline using TOPOLOGY_POINT_LIST and write PointSize in vertex shader function.");
 
@@ -27,7 +29,6 @@ TEST_F(PositivePipelineTopology, PointSizeWriteInFunction) {
         CreatePipelineHelper pipe(*this);
         pipe.shader_stages_ = {vs.GetStageCreateInfo(), ps.GetStageCreateInfo()};
         pipe.ia_ci_.topology = VK_PRIMITIVE_TOPOLOGY_POINT_LIST;
-        pipe.InitState();
         pipe.CreateGraphicsPipeline();
     }
 }
@@ -50,7 +51,6 @@ TEST_F(PositivePipelineTopology, PointSizeGeomShaderSuccess) {
     pipe.shader_stages_ = {vs.GetStageCreateInfo(), gs.GetStageCreateInfo(), ps.GetStageCreateInfo()};
     // Set Input Assembly to TOPOLOGY POINT LIST
     pipe.ia_ci_.topology = VK_PRIMITIVE_TOPOLOGY_POINT_LIST;
-    pipe.InitState();
     pipe.CreateGraphicsPipeline();
 }
 
@@ -164,12 +164,11 @@ TEST_F(PositivePipelineTopology, LoosePointSizeWrite) {
         pipe.shader_stages_ = {vs.GetStageCreateInfo(), ps.GetStageCreateInfo()};
         // Set Input Assembly to TOPOLOGY POINT LIST
         pipe.ia_ci_.topology = VK_PRIMITIVE_TOPOLOGY_POINT_LIST;
-        pipe.InitState();
         pipe.CreateGraphicsPipeline();
     }
 }
 
-TEST_F(PositivePipelineTopology, PointSizeStructMemeberWritten) {
+TEST_F(PositivePipelineTopology, PointSizeStructMemberWritten) {
     TEST_DESCRIPTION("Write built-in PointSize within a struct");
 
     SetTargetApiVersion(VK_API_VERSION_1_1); // At least 1.1 is required for maintenance4
@@ -272,40 +271,39 @@ TEST_F(PositivePipelineTopology, PointSizeStructMemeberWritten) {
     )asm";
     auto vs = VkShaderObj::CreateFromASM(this, vs_src.c_str(), VK_SHADER_STAGE_VERTEX_BIT);
 
-    if (vs) {
-        // struct has {
-        //     mat4x4
-        //     float
-        //     vec4
-        // }
-        // but std140 padding so the vec4 is offset 80
-        VkPushConstantRange push_constant_ranges[1]{{VK_SHADER_STAGE_VERTEX_BIT, 0, 96}};
-
-        VkPipelineLayoutCreateInfo const pipeline_layout_info{
-            VK_STRUCTURE_TYPE_PIPELINE_LAYOUT_CREATE_INFO, nullptr, 0, 0, nullptr, 1, push_constant_ranges};
-
-        VkVertexInputBindingDescription input_binding[2] = {
-            {0, 16, VK_VERTEX_INPUT_RATE_VERTEX},
-            {1, 16, VK_VERTEX_INPUT_RATE_VERTEX},
-        };
-        VkVertexInputAttributeDescription input_attribs[2] = {
-            {0, 0, VK_FORMAT_R32G32B32A32_SFLOAT, 0},
-            {1, 1, VK_FORMAT_R32G32B32A32_SFLOAT, 0},
-        };
-
-        CreatePipelineHelper pipe(*this);
-        pipe.shader_stages_ = {vs->GetStageCreateInfo(), pipe.fs_->GetStageCreateInfo()};
-        pipe.pipeline_layout_ci_ = pipeline_layout_info;
-        pipe.ia_ci_.topology = VK_PRIMITIVE_TOPOLOGY_POINT_LIST;
-        pipe.vi_ci_.pVertexBindingDescriptions = input_binding;
-        pipe.vi_ci_.vertexBindingDescriptionCount = 2;
-        pipe.vi_ci_.pVertexAttributeDescriptions = input_attribs;
-        pipe.vi_ci_.vertexAttributeDescriptionCount = 2;
-        pipe.InitState();
-        pipe.CreateGraphicsPipeline();
-    } else {
-        printf("Error creating shader from assembly\n");
+    if (!vs) {
+        GTEST_SKIP() << "Error creating shader from assembly";
     }
+
+    // struct has {
+    //     mat4x4
+    //     float
+    //     vec4
+    // }
+    // but std140 padding so the vec4 is offset 80
+    VkPushConstantRange push_constant_ranges[1]{{VK_SHADER_STAGE_VERTEX_BIT, 0, 96}};
+
+    VkPipelineLayoutCreateInfo const pipeline_layout_info{
+        VK_STRUCTURE_TYPE_PIPELINE_LAYOUT_CREATE_INFO, nullptr, 0, 0, nullptr, 1, push_constant_ranges};
+
+    VkVertexInputBindingDescription input_binding[2] = {
+        {0, 16, VK_VERTEX_INPUT_RATE_VERTEX},
+        {1, 16, VK_VERTEX_INPUT_RATE_VERTEX},
+    };
+    VkVertexInputAttributeDescription input_attribs[2] = {
+        {0, 0, VK_FORMAT_R32G32B32A32_SFLOAT, 0},
+        {1, 1, VK_FORMAT_R32G32B32A32_SFLOAT, 0},
+    };
+
+    CreatePipelineHelper pipe(*this);
+    pipe.shader_stages_ = {vs->GetStageCreateInfo(), pipe.fs_->GetStageCreateInfo()};
+    pipe.pipeline_layout_ci_ = pipeline_layout_info;
+    pipe.ia_ci_.topology = VK_PRIMITIVE_TOPOLOGY_POINT_LIST;
+    pipe.vi_ci_.pVertexBindingDescriptions = input_binding;
+    pipe.vi_ci_.vertexBindingDescriptionCount = 2;
+    pipe.vi_ci_.pVertexAttributeDescriptions = input_attribs;
+    pipe.vi_ci_.vertexAttributeDescriptionCount = 2;
+    pipe.CreateGraphicsPipeline();
 }
 
 TEST_F(PositivePipelineTopology, PolygonModeValid) {
@@ -315,11 +313,11 @@ TEST_F(PositivePipelineTopology, PolygonModeValid) {
     InitRenderTarget();
 
     std::vector<const char *> device_extension_names;
-    auto features = m_device->phy().features();
+    auto features = m_device->Physical().Features();
     // Artificially disable support for non-solid fill modes
     features.fillModeNonSolid = false;
     // The sacrificial device object
-    vkt::Device test_device(gpu(), device_extension_names, &features);
+    vkt::Device test_device(Gpu(), device_extension_names, &features);
 
     VkAttachmentReference attach = {};
     attach.layout = VK_IMAGE_LAYOUT_GENERAL;
@@ -359,7 +357,6 @@ TEST_F(PositivePipelineTopology, PolygonModeValid) {
     {
         CreatePipelineHelper pipe(*this);
         pipe.device_ = &test_device;
-        pipe.InitState();
         pipe.shader_stages_ = {vs.GetStageCreateInfo(), fs.GetStageCreateInfo()};
         pipe.gp_ci_.layout = pipeline_layout.handle();
         pipe.gp_ci_.renderPass = render_pass.handle();
@@ -392,7 +389,6 @@ TEST_F(PositivePipelineTopology, NotPointSizeGeometry) {
     CreatePipelineHelper pipe(*this);
     pipe.shader_stages_ = {pipe.vs_->GetStageCreateInfo(), gs.GetStageCreateInfo(), pipe.fs_->GetStageCreateInfo()};
     pipe.ia_ci_.topology = VK_PRIMITIVE_TOPOLOGY_POINT_LIST;
-    pipe.InitState();
 
     pipe.CreateGraphicsPipeline();
 }
@@ -400,6 +396,7 @@ TEST_F(PositivePipelineTopology, NotPointSizeGeometry) {
 TEST_F(PositivePipelineTopology, Rasterizer) {
     TEST_DESCRIPTION("Test topology set when creating a pipeline with tessellation and geometry shader.");
 
+    AddRequiredFeature(vkt::Feature::geometryShader);
     AddRequiredFeature(vkt::Feature::tessellationShader);
     RETURN_IF_SKIP(Init());
 
@@ -446,17 +443,16 @@ TEST_F(PositivePipelineTopology, Rasterizer) {
     pipe.shader_stages_.emplace_back(gs.GetStageCreateInfo());
     pipe.shader_stages_.emplace_back(tcs.GetStageCreateInfo());
     pipe.shader_stages_.emplace_back(tes.GetStageCreateInfo());
-    pipe.InitState();
     pipe.AddDynamicState(VK_DYNAMIC_STATE_LINE_WIDTH);
     pipe.CreateGraphicsPipeline();
 
-    m_commandBuffer->begin();
-    m_commandBuffer->BeginRenderPass(renderPass(), framebuffer(), 32, 32, m_renderPassClearValues.size(),
+    m_command_buffer.Begin();
+    m_command_buffer.BeginRenderPass(RenderPass(), Framebuffer(), 32, 32, m_renderPassClearValues.size(),
                                      m_renderPassClearValues.data());
-    vk::CmdBindPipeline(m_commandBuffer->handle(), VK_PIPELINE_BIND_POINT_GRAPHICS, pipe.pipeline_);
-    vk::CmdDraw(m_commandBuffer->handle(), 4, 1, 0, 0);
-    m_commandBuffer->EndRenderPass();
-    m_commandBuffer->end();
+    vk::CmdBindPipeline(m_command_buffer.handle(), VK_PIPELINE_BIND_POINT_GRAPHICS, pipe.Handle());
+    vk::CmdDraw(m_command_buffer.handle(), 4, 1, 0, 0);
+    m_command_buffer.EndRenderPass();
+    m_command_buffer.End();
 }
 
 TEST_F(PositivePipelineTopology, LineTopologyClasses) {
@@ -471,7 +467,7 @@ TEST_F(PositivePipelineTopology, LineTopologyClasses) {
 
     // Verify each vkCmdSet command
     CreatePipelineHelper pipe(*this);
-    pipe.AddDynamicState(VK_DYNAMIC_STATE_PRIMITIVE_TOPOLOGY_EXT);
+    pipe.AddDynamicState(VK_DYNAMIC_STATE_PRIMITIVE_TOPOLOGY);
     pipe.vi_ci_.vertexBindingDescriptionCount = 1;
     VkVertexInputBindingDescription inputBinding = {0, sizeof(float), VK_VERTEX_INPUT_RATE_VERTEX};
     pipe.vi_ci_.pVertexBindingDescriptions = &inputBinding;
@@ -479,23 +475,22 @@ TEST_F(PositivePipelineTopology, LineTopologyClasses) {
     VkVertexInputAttributeDescription attribute = {0, 0, VK_FORMAT_R32_SFLOAT, 0};
     pipe.vi_ci_.pVertexAttributeDescriptions = &attribute;
     pipe.ia_ci_.topology = VK_PRIMITIVE_TOPOLOGY_LINE_LIST;
-    pipe.InitState();
     pipe.CreateGraphicsPipeline();
 
     vkt::Buffer vbo(*m_device, sizeof(float) * 3, VK_BUFFER_USAGE_VERTEX_BUFFER_BIT);
 
-    vkt::CommandBuffer cb(m_device, m_commandPool);
-    cb.begin();
+    vkt::CommandBuffer cb(*m_device, m_command_pool);
+    cb.Begin();
     cb.BeginRenderPass(m_renderPassBeginInfo);
 
-    vk::CmdBindPipeline(cb.handle(), VK_PIPELINE_BIND_POINT_GRAPHICS, pipe.pipeline_);
+    vk::CmdBindPipeline(cb.handle(), VK_PIPELINE_BIND_POINT_GRAPHICS, pipe.Handle());
     vk::CmdBindVertexBuffers(cb.handle(), 0, 1, &vbo.handle(), &kZeroDeviceSize);
     vk::CmdSetPrimitiveTopologyEXT(cb.handle(), VK_PRIMITIVE_TOPOLOGY_LINE_LIST_WITH_ADJACENCY);
     vk::CmdDraw(cb.handle(), 1, 1, 0, 0);
 
     cb.EndRenderPass();
 
-    cb.end();
+    cb.End();
 }
 
 TEST_F(PositivePipelineTopology, PointSizeDynamicAndUnestricted) {
@@ -570,3 +565,23 @@ TEST_F(PositivePipelineTopology, PointSizeMaintenance5) {
     };
     CreatePipelineHelper::OneshotTest(*this, set_info, kErrorBit);
 }
+
+TEST_F(PositivePipelineTopology, PrimitiveTopologyListRestartDynamic) {
+    TEST_DESCRIPTION("Ignore invalid primitiveRestartEnable");
+    SetTargetApiVersion(VK_API_VERSION_1_1);
+    AddRequiredExtensions(VK_EXT_PRIMITIVE_TOPOLOGY_LIST_RESTART_EXTENSION_NAME);
+    AddRequiredExtensions(VK_EXT_EXTENDED_DYNAMIC_STATE_2_EXTENSION_NAME);
+    AddRequiredFeature(vkt::Feature::extendedDynamicState2);
+
+    RETURN_IF_SKIP(Init());
+    InitRenderTarget();
+
+    VkShaderObj vs(this, kVertexPointSizeGlsl, VK_SHADER_STAGE_VERTEX_BIT);
+
+    CreatePipelineHelper pipe(*this);
+    pipe.AddDynamicState(VK_DYNAMIC_STATE_PRIMITIVE_RESTART_ENABLE);
+    pipe.ia_ci_.topology = VK_PRIMITIVE_TOPOLOGY_POINT_LIST;
+    pipe.ia_ci_.primitiveRestartEnable = VK_TRUE;
+    pipe.shader_stages_ = {vs.GetStageCreateInfo(), pipe.fs_->GetStageCreateInfo()};
+    pipe.CreateGraphicsPipeline();
+}
\ No newline at end of file
