@@ -457,10 +457,6 @@ TEST_F(NegativeTransformFeedback, ExecuteSecondaryCommandBuffers) {
     m_errorMonitor->SetDesiredError("VUID-vkCmdBeginTransformFeedbackEXT-commandBuffer-recording");
     vk::CmdBeginTransformFeedbackEXT(m_command_buffer.handle(), 0, 1, nullptr, nullptr);
     m_errorMonitor->VerifyFound();
-    // TODO - When proper VU above is added, see if 02286 is still needed
-    // m_errorMonitor->SetDesiredError("VUID-vkCmdExecuteCommands-None-02286");
-    // vk::CmdExecuteCommands(m_command_buffer.handle(), 1, &secondary.handle());
-    // m_errorMonitor->VerifyFound();
 }
 
 TEST_F(NegativeTransformFeedback, BindPipeline) {
@@ -1146,3 +1142,48 @@ TEST_F(NegativeTransformFeedback, InvalidCounterBuffers) {
     m_command_buffer.EndRenderPass();
     m_command_buffer.End();
 }
+
+TEST_F(NegativeTransformFeedback, ExecuteSecondaryCommandBuffersWithDynamicRenderPass) {
+    TEST_DESCRIPTION("Call CmdExecuteCommandBuffers when transform feedback is active");
+    SetTargetApiVersion(VK_API_VERSION_1_3);
+    AddRequiredExtensions(VK_KHR_MAINTENANCE_7_EXTENSION_NAME);
+    AddRequiredFeature(vkt::Feature::dynamicRendering);
+    AddRequiredFeature(vkt::Feature::maintenance7);
+    RETURN_IF_SKIP(InitBasicTransformFeedback());
+
+    InitRenderTarget();
+
+    vkt::CommandBuffer secondary_cb(*m_device, m_command_pool, VK_COMMAND_BUFFER_LEVEL_SECONDARY);
+
+    VkFormat format = m_renderTargets[0]->Format();
+    VkCommandBufferInheritanceRenderingInfo inheritance_rendering_info = vku::InitStructHelper();
+    inheritance_rendering_info.colorAttachmentCount = 1u;
+    inheritance_rendering_info.pColorAttachmentFormats = &format;
+    inheritance_rendering_info.rasterizationSamples = VK_SAMPLE_COUNT_1_BIT;
+
+    VkCommandBufferInheritanceInfo inheritance_info = vku::InitStructHelper(&inheritance_rendering_info);
+
+    VkCommandBufferBeginInfo secondary_begin = vku::InitStructHelper();
+    secondary_begin.flags = VK_COMMAND_BUFFER_USAGE_RENDER_PASS_CONTINUE_BIT;
+    secondary_begin.pInheritanceInfo = &inheritance_info;
+    secondary_cb.Begin(&secondary_begin);
+    secondary_cb.End();
+
+    CreatePipelineHelper pipe(*this);
+    auto vs = VkShaderObj::CreateFromASM(this, kXfbVsSource, VK_SHADER_STAGE_VERTEX_BIT);
+    pipe.shader_stages_[0] = vs->GetStageCreateInfo();
+    pipe.CreateGraphicsPipeline();
+
+    m_command_buffer.Begin();
+    vk::CmdBindPipeline(m_command_buffer.handle(), VK_PIPELINE_BIND_POINT_GRAPHICS, pipe.Handle());
+    m_command_buffer.BeginRenderPass(m_renderPassBeginInfo, VK_SUBPASS_CONTENTS_INLINE_AND_SECONDARY_COMMAND_BUFFERS_KHR);
+    vk::CmdBeginTransformFeedbackEXT(m_command_buffer.handle(), 0u, 0u, NULL, NULL);
+
+    m_errorMonitor->SetDesiredError("VUID-vkCmdExecuteCommands-None-02286");
+    vk::CmdExecuteCommands(m_command_buffer.handle(), 1, &secondary_cb.handle());
+    m_errorMonitor->VerifyFound();
+
+    vk::CmdEndTransformFeedbackEXT(m_command_buffer.handle(), 0u, 0u, NULL, NULL);
+    m_command_buffer.EndRenderPass();
+    m_command_buffer.End();
+}
